from ei.core.applications import create_application


def test_create_application() -> None:
    create_application()
